(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    132794,       2461]
NotebookOptionsPosition[    130843,       2422]
NotebookOutlinePosition[    131250,       2438]
CellTagsIndexPosition[    131207,       2435]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Conics", "Title",
 CellChangeTimes->{{3.858660027577594*^9, 
  3.858660034451033*^9}},ExpressionUUID->"7e0e5b54-d4c9-49bc-b7ed-\
1666862a7182"],

Cell["Marvin Zanke & Leon von Detten", "Author",
 CellChangeTimes->{{3.858661518507442*^9, 3.858661525372672*^9}, {
  3.860145661880639*^9, 
  3.860145664599019*^9}},ExpressionUUID->"b8f31c66-9c73-4224-8603-\
aa2d294b28eb"],

Cell["11.04 .2022", "Date",
 CellChangeTimes->{{3.8586615278698874`*^9, 
  3.85866153429884*^9}},ExpressionUUID->"97dd6f8c-0a6c-49b3-a42e-\
577c144dc25b"],

Cell[TextData[{
 "In this notebook, we plot a conic for variable input parameters, see also \
exercise sheet 2, A.2). The generic parameterization of a conic is given by \
r(\[Phi]) = ",
 Cell[BoxData[
  FormBox[
   FractionBox["p", 
    RowBox[{"1", "-", 
     RowBox[{"\[Epsilon]", "*", 
      RowBox[{"cos", "(", "\[Phi]", ")"}]}]}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "cbae50ba-eb61-49c4-86be-9f709af5865b"],
 " in polar coordinates, see, e.g., \
<https://en.wikipedia.org/wiki/Conic_section>, with \[Epsilon] the \
eccentricity, \[Epsilon]=0: circle; 0<\[Epsilon]<1: ellipse; \[Epsilon]=1: \
parabola; \[Epsilon]>1: hyperbola. For the Kepler problem, we had \
r(\[Phi])=",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"\[VerticalSeparator]", 
     RowBox[{
      OverscriptBox["L", "\[RightVector]"], "'"}], 
     SuperscriptBox["\[VerticalSeparator]", "2"]}], 
    RowBox[{"\[Mu]", "*", "\[Kappa]"}]], 
   FractionBox["1", 
    RowBox[{"\[VerticalSeparator]", 
     OverscriptBox["B", "\[RightVector]"], "\[VerticalSeparator]", 
     RowBox[{
      RowBox[{"*", "cos", 
       RowBox[{"(", "\[Phi]", ")"}]}], "-", "1"}]}]]}]],ExpressionUUID->
  "8dc0faac-0481-438f-9dd9-093759872fca"],
 ", i.e., the magnitude of the Runge-Lenz vector \[VerticalSeparator]",
 Cell[BoxData[
  OverscriptBox["B", "\[RightVector]"]],
  CellChangeTimes->{{3.8586600869273853`*^9, 3.858660272128779*^9}, {
   3.858660328025797*^9, 3.858660461194663*^9}, {3.858660500410325*^9, 
   3.858660500575886*^9}, {3.858660768238616*^9, 3.8586607854366217`*^9}, {
   3.8586613566341343`*^9, 3.8586613587594557`*^9}, {3.860146397000141*^9, 
   3.8601464026279507`*^9}, {3.860146466364624*^9, 3.860146488855529*^9}, {
   3.8601465345850687`*^9, 3.8601465730232973`*^9}},ExpressionUUID->
  "ea13fd9a-dc3c-4747-93bb-33ae21ce14c3"],
 "\[VerticalSeparator] takes the role of the eccentricity. Furthermore, \
\[Kappa]>0 corresponds to a repulsive force and \[Kappa]<0 to an attractive \
force."
}], "Text",
 CellChangeTimes->{{3.8601463854562798`*^9, 3.8601465939430313`*^9}, {
  3.860146798820418*^9, 
  3.8601468094689198`*^9}},ExpressionUUID->"fcb346d3-3e64-490f-950c-\
a4515cd34d00"],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.860146672751521*^9, 
  3.860146681461401*^9}},ExpressionUUID->"c2244fe2-1cb9-4f0a-b470-\
082978e883e4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "the", " ", "route", " ", "r", " ", "of", " ", "the", " ", 
    RowBox[{"conic", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"r", "[", 
     RowBox[{
     "\[Phi]_", ",", "B_", ",", "L_", ",", "\[Mu]_", ",", "\[Kappa]_"}], 
     "]"}], ":=", 
    RowBox[{
     FractionBox[
      SuperscriptBox["L", "2"], 
      RowBox[{"\[Mu]", "*", "\[Kappa]"}]], "*", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"B", "*", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", "1"}]]}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.858660533970078*^9, 3.8586605955375032`*^9}, {
  3.858660658451332*^9, 3.8586606681758432`*^9}, {3.858660730465684*^9, 
  3.858660735038094*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"1a649f67-a2d0-441e-ad5c-12fc7f248f66"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Define", " ", "the", " ", "unit", " ", "vector", " ", 
     SubscriptBox[
      OverscriptBox["e", "\[RightVector]"], "r"], " ", "in", " ", "polar", 
     " ", "coordinates"}], ",", " ", 
    RowBox[{
     RowBox[{"which", " ", "fulfills", " ", 
      OverscriptBox["r", "\[RightVector]"], 
      RowBox[{"(", "\[Phi]", ")"}]}], "=", 
     RowBox[{"r", 
      RowBox[{"(", "\[Phi]", ")"}], 
      RowBox[{
       SubscriptBox[
        OverscriptBox["e", "\[RightVector]"], "r"], "."}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"er", "=", 
    RowBox[{"(", GridBox[{
       {
        RowBox[{"Cos", "[", "\[Phi]", "]"}]},
       {
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}
      }], ")"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.858661015894655*^9, 3.858661071468059*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"2ea0a885-a7f9-46d8-9ada-90fe064da19f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "the", " ", "vector", " ", 
    OverscriptBox["r", "\[RightVector]"], 
    RowBox[{"(", "\[Phi]", ")"}], " ", "that", " ", "we", " ", "want", " ", 
    "to", " ", 
    RowBox[{"plot", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"rV", "[", 
     RowBox[{
     "\[Phi]_", ",", "B_", ",", "L_", ",", "\[Mu]_", ",", "\[Kappa]_"}], 
     "]"}], ":=", 
    RowBox[{
     RowBox[{"r", "[", 
      RowBox[{"\[Phi]", ",", "B", ",", "L", ",", "\[Mu]", ",", "\[Kappa]"}], 
      "]"}], "er"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.858661117964943*^9, 3.858661153638577*^9}, {
  3.858661388020755*^9, 3.858661388849678*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"2c7ce0b9-e34b-4335-b970-7bdde6b3698c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots", "Section",
 CellChangeTimes->{{3.860146686009953*^9, 
  3.860146691898267*^9}},ExpressionUUID->"bc33fae6-c60a-48dc-bb50-\
c0f5e7b4e1da"],

Cell["\<\
Plot the conic for fixed values of B, L, \[Mu], and \[Kappa], where \[Phi] \
remains a plot parameter. At this, L=1 and \[Mu]=1 are fixed (arbitrarily). \
To make the distinction between a parabola and hyperbola more apparent in the \
plots, we adjust the (plot) range for some of these.\
\>", "Text",
 CellChangeTimes->{{3.86014664299854*^9, 
  3.860146649833358*^9}},ExpressionUUID->"f251f2d5-078a-4c82-92cb-\
cd955563a4dc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"\[Kappa]", "=", 
     RowBox[{
      RowBox[{"1", ">", 
       RowBox[{"0.", " ", "\[Epsilon]"}]}], "=", "0"}]}], ",", " ", 
    RowBox[{"\[Epsilon]", "=", "0.9"}], ",", " ", 
    RowBox[{"\[Epsilon]", "=", "1"}], ",", " ", 
    RowBox[{
     RowBox[{"and", " ", "\[Epsilon]"}], "=", 
     RowBox[{"1.1", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"rV", "[", 
        RowBox[{"\[Phi]", ",", "0", ",", "1", ",", "1", ",", "1"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"rV", "[", 
        RowBox[{"\[Phi]", ",", "0.9", ",", "1", ",", "1", ",", "1"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"rV", "[", 
        RowBox[{"\[Phi]", ",", "1", ",", "1", ",", "1", ",", "1"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"rV", "[", 
        RowBox[{"\[Phi]", ",", "1.1", ",", "1", ",", "1", ",", "1"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10"}], ",", "20"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}]}], "]"}]}], 
    "}"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"\[Kappa]", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "<", 
        RowBox[{"0.", " ", "\[Epsilon]"}]}], "=", "0"}]}], ",", " ", 
     RowBox[{"\[Epsilon]", "=", "0.9"}], ",", " ", 
     RowBox[{"\[Epsilon]", "=", "1"}], ",", " ", 
     RowBox[{
      RowBox[{"and", " ", "\[Epsilon]"}], "=", 
      RowBox[{"1.1", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"rV", "[", 
        RowBox[{"\[Phi]", ",", "0", ",", "1", ",", "1", ",", 
         RowBox[{"-", "1"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"rV", "[", 
        RowBox[{"\[Phi]", ",", "0.9", ",", "1", ",", "1", ",", 
         RowBox[{"-", "1"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"rV", "[", 
        RowBox[{"\[Phi]", ",", "1", ",", "1", ",", "1", ",", 
         RowBox[{"-", "1"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "20"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"rV", "[", 
        RowBox[{"\[Phi]", ",", "1.1", ",", "1", ",", "1", ",", 
         RowBox[{"-", "1"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}]}], "]"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.8586615638099117`*^9, 3.858661622360228*^9}, {
  3.858661746882324*^9, 3.8586618609898453`*^9}, {3.858661900697613*^9, 
  3.8586621371861467`*^9}, {3.8586621986363373`*^9, 3.8586622037948627`*^9}, {
  3.8586624455008783`*^9, 3.85866244828675*^9}, {3.860146653212184*^9, 
  3.8601466617837553`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"48f75573-507c-4a82-aa7b-808cb401d832"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    GraphicsBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw1m3c8lf///42KyCiiUtFCg4rS7qloGBklVN5ZDSGzFFkpKZQ9ykpky5b9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          "]]},
        Annotation[#, "Charting`Private`Tag$4565#1"]& ]}, {}},
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     BaseStyle->{FontFamily -> "Arial"},
     DisplayFunction->Identity,
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{
      "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "ScalingFunctions" -> None},
     PlotRange->{{-1., 0.9999998831351729}, {-0.9999998782744886, 
      0.9999998592812047}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", 
    GraphicsBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw12nk01N//OPCZITvZszNGhGRLIXVf8o4oFEJlKy0SilZbIpKt7CHJXkSU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          "]]},
        Annotation[#, "Charting`Private`Tag$4627#1"]& ]}, {}},
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     BaseStyle->{FontFamily -> "Arial"},
     DisplayFunction->Identity,
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{
      "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "ScalingFunctions" -> None},
     PlotRange->{{-10.000000000000002`, 
      0.5263157571011541}, {-2.294156791159831, 2.2941565394334447`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", 
    GraphicsBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwV1nc8lu8XB3B5JCshJKTsvVdGrltWSjIqZc8oSuHbsBJZoWEUKSOJVIjM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          "]]},
        Annotation[#, "Charting`Private`Tag$4659#1"]& ]}, {}},
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     BaseStyle->{FontFamily -> "Arial"},
     DisplayFunction->Identity,
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{
      "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "ScalingFunctions" -> None},
     PlotRange->{{-20, 5}, {-5, 5}},
     PlotRangeClipping->True,
     PlotRangePadding->{{0, 0}, {0, 0}},
     Ticks->{Automatic, Automatic}], ",", 
    GraphicsBox[{{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwtjXswFHgAx/esdAhLYifpit86Spu3rfD7UpO33JZEFGpFDyVxymuPSyrN
EXWqUQmHEEVCtLJHXIQ6j9Y5ia045TWUY+o0c5+Z73zn88/3uzrgKF8gw2Aw
3Bbytee+fEUXjP8ZjnHZyWYQfHJ6cqLiYRo9P3fP23/Bpw8scmXWZNMiUYVq
74IXeCuxG64W05tyf8ef/oag/kpNg0VtGdUwLKv0kyGIune6O6e4km5waaw7
zCTYeOc7jxfXa+la35LCAlkC6KuGnXB4TPvrWBc05Qg2ZTM4cvVimuR+Napi
8cJ/hjzXxKqRWr9ekpooT6AS0Ka45EETrXG0GTmjSNAu+OiaZ/KUKnZp51Ur
EciqWGZolrRSV5eqkZUsAmVVUz5Po51aBdj1lqsRGM046ezz6KB3fWoORbAJ
NhQkntnd+YJK6+cP3NJa2E+XmFlrdFIjz55mxncEtgoP9zR4dtGY0K6rHnoE
W26EqU7+1UMnRhOELmsI2OI7NoWrJDQ/cLoygkuQX3jG1EzQSx+pZZkFWhII
kjvy+sf76O7IdnlDK4Jn/pejNXn9dKCvwUPPlqBxSn6Q4BWtyXPKrHIm0HnG
fjx0doCOiv9p3r+PYDJxnm9Jhij3eKlWTzCBpYLrRq+WIaq5Zktf/DEChg+/
hhMupRL25R+FsQRLX1YndzW9oT83px8xyCRYx8lt2HxymJrZHE8U5BJ4tRof
DPx+hFbbD6j0FRNsjpd0CLpGaLGvcYtQROC/gy9eZjlKLzRdCy6SEtwOMNWf
Z45R/sGdgs4xgqTmByaNVWM0teeLHP2XoM86vY3PG6eZVu9tulU4GPT5KXtg
fJyqC/PfGttw0O2ta2kYPElL/8gZ3JXPQcnnGH+TU9M0VltJzaSSg4KJ16ud
301TU1aJenATB0F1Sje8PWco55Vs48wwB17nJH9G8j5SB1YRQ2Ssh9kRt+HI
xbPUoNVzMLtTD0fdOZZ+/fO0YmuEy9k4fUieOrdu65OBwKe6w/OGPjK+bBWH
GTIxbL5/90uRPq7HpbjVRjMRpM0QLmYaIGj76eTBVbLQypGT/nrRAC9FWUpx
kYuQHtS2NrR3DcQd19fzQr5F6578qBZHLpJtFN+69ahA006n6HkSF+3uH6Rv
17FQnMO9f7iZiy7rSn+VUBZ22DEy0reth4FbYvCTORbWOW4Ivcczwjjx8ztE
1JA9bFBYesEY5VOz7y92qKM+cOZzZpA5npWRgbztKxDewizvrDKHEW+20nls
BbKnoKGlbAHWp98kcSnaYM9dkQrrLPCpajK5f2glEj6oeu3n87A37IcHE2Or
EJ43v/x+kBVkdzWejGsiuCTAu+ZdW3E33T5QMmmMo93bgqm5PZQvpcl6PDJB
adbyrHHigE1zZcUh10zBuHQ4RsbRCeejdYpS0s2RcjEmKkrBHboJEUtNRjai
KHQUCp/dca08Z/mi21ZIMdQd01Ljw2hOJArJtUGWT4bSk6odMHb9fZghtsWU
VG+mJs0XzMl4euq1I+7fst27+rIfolI5We1cV/jdzrbvlgaAHbuzbUmFO6LP
qanXOh3EqSTn0rQYTyx7nuSg4X8MFSLlWzqHfJEgjX2fLw6HzJ3eVIvcfYBG
l1eynRBFIzdlJ4RHoKr4Kr9M/he8CZFJ7XOOxn/ZBSsZ
           "]], 
          LineBox[CompressedData["
1:eJwl2Hc8Vu/7AHAyipDZICNF2YRE4zoRUaiQj4TsFC1bhZKRT5kZJR5C9t77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           "]], LineBox[CompressedData["
1:eJwVj3s01Gkcxo1r08xK5dKS2/iNGTORNCiUb4p1qzbJMlnXHZ3adSmjXCOF
0lmXMM7uESlZE46J2XWKel+L1uWgjJJaDMYtbRJlKKyec57znM8/z3Me45BI
L56igoLC0XV/TQ2KtKKOnA3vIhRzBz0S8Rz95bPT0liArKqR1OQwzGffjpRq
noOMf+4XkZ2DMC1uwbYn6hdgvNFuGojxw3VHIOfy51BAMe2hleJjuFwkc3Ww
84NrzfN2gzJn3Jx4KsYl8TBoNqnOdKXvwZ3u1lmbFjygRfKoT6JviwsDNk70
57uDiJr18cwra+zPYnax7FzBiSzsIdXsxr3UWwmTZYfgjk5SGS3IEgvTagdT
NAFKXEtvb3VjYppR3FnKsA28i8623mBoiMWx/q38JBtI9mTXaPEM8NPrZbHN
hjbADxyd3lerj41+/TbPMtIa5oVbPjkFbce+1VcLFTkcONjFfBRF0sU1biP1
qtZWsKwnI9Vv18YTNJJhwogFyHu/FJEyNfBFrxTf6VsWAKHiqCUXDcxNL6uZ
CraAmJ0Sqo+KBs75oaozbMocnI4OeOtRN2HO8hV1TVVz0G69OJa24xvsnqdp
djyBDcmcQL6ehIw7P5xqCd9mBiLeSHadtzJezhJU3pAzoVamLUhSU8adL8lw
coAJYMQd9mlQwqft/DPaipjgyJvo1TVVwvs3l8zeZzEh9g92obmaIs7ZJS+i
BjHAoer543zZGqq4uztg0pUBkXrfUezD1lDL2rCHjRUDFDF4uk6vorsmJzsY
qgxgmFfE8edXUHcTrc+gzhQc3raZsXS+oBVjD/FDQ1PYOp1vFVEgR4ZJ3HNr
VFPYMkKJCNaXo8hgE6lomQ5PBU+ML5UvovyEaCuvfjrovpjPpjd+Qu167cP+
BXSYUm80YC8soO7w15K+NDoMW5JMhFcWUJPgv9bK83TYJpcP6WgvoLSa6s4o
PzrM+bS8rbKfRyXhM2q7TOigILonVsqdQyU7TjjEa9NhiJlT5s2cQ5lteRM6
G+nA+Pvy65/wezS6t8rI8wMBKpTFar/xWdR9nSaJf0IAW7Lzx8zHb1GzZbyO
eyMB6ilOR+cXZ9DDqahWXi0BMoG3SYbVDEr+kCW/WEJAXXa4FblyGpXfPnGT
lkTAvXQ3Jr9iAgWkC/r3xxDQWK9savlmHD0avxZVGk5AgO1qSveOcTQ4xt9n
G0gAJ8OhPEc8hlY0lA+c9iUgkeM2eWdpFAlPcpyGjxHQciE9KtZxFKU6yY0K
nAkYqj5wwblLioLSHNckjgS0Hl4ECy0p4nO5/3rbEZB6avDZ2YYhlKug0adr
SUDt3pQO1shrZMFj6weyCUjqKD4jinmFtq6+bxozJeC4Pbq/jzKA2h8cqa8y
WO8z4v3J2fsCcTsyg9/rEnCE2p566VkfoooLdaN1CFjpkWkWnZGgC/l7ijia
BCT//Nz+vHIvUhMfvMvZTIDG91IpqeQp6hEWLJ1TX9/v1SKH8LvRcppKyCyF
gGuss3EzlZ2ItupXJSSv/1G5ybsia0NDhY6VpWoE9PY/OLjZ4Akq6XK06Vch
gOH5u/C8bzMaYD0wc1cm4Op2pttveRg5+r8MW1YkIJRWOtBQ3IAirG5IJkkE
LPnMTnrp/IUs84q5W9Z544bR4qYcESry48/EKRCQX/1x8Y5WOWo3dok3WGdB
bojLHi0B+rz2VSagFD2AajZNNP4P371dZw==
           "]]},
         Annotation[#, 
          "Charting`Private`Tag$4689#1"]& ], {}}, {{}, {}}, {{}, {}}}, {}},
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     BaseStyle->{FontFamily -> "Arial"},
     DisplayFunction->Identity,
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{
      "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "ScalingFunctions" -> None},
     PlotRange->{{-10, 20}, {-10, 10}},
     PlotRangeClipping->True,
     PlotRangePadding->{{0, 0}, {0, 0}},
     Ticks->{Automatic, Automatic}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.858661584335528*^9, 3.8586616237135*^9}, {
   3.858661751443453*^9, 3.858661861232752*^9}, {3.858661913435207*^9, 
   3.8586619395043707`*^9}, {3.858662089403344*^9, 3.858662105357795*^9}, 
   3.858662137601261*^9, 3.858662434291745*^9, 3.85866247902349*^9, 
   3.860146838228526*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"82141fab-54e0-4b3f-a327-a0ab3b01ad7c"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    GraphicsBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw1m3c8lf///42KyCiiUtFCg4rS7qloGBklVN5ZDSGzFFkpKZQ9ykpky5b9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          "]]},
        Annotation[#, "Charting`Private`Tag$4719#1"]& ]}, {}},
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     BaseStyle->{FontFamily -> "Arial"},
     DisplayFunction->Identity,
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{
      "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "ScalingFunctions" -> None},
     PlotRange->{{-0.9999998831351729, 1.}, {-0.9999998592812047, 
      0.9999998782744886}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", 
    GraphicsBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw12nk01N//OPCZITvZszNGhGRLoeXe8o4oFEJlKy0SilZbIpKt7CH7VkSU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          "]]},
        Annotation[#, "Charting`Private`Tag$4747#1"]& ]}, {}},
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     BaseStyle->{FontFamily -> "Arial"},
     DisplayFunction->Identity,
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{
      "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "ScalingFunctions" -> None},
     PlotRange->{{-0.5263157571011541, 
      10.000000000000002`}, {-2.2941565394334447`, 2.294156791159831}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], ",", 
    GraphicsBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwV1nc8V98fB3D5ICsrZCV775mRc2QlklEpe4YoGd+GlcgKDaNIGSFSIZvi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          "]]},
        Annotation[#, "Charting`Private`Tag$4775#1"]& ]}, {}},
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     BaseStyle->{FontFamily -> "Arial"},
     DisplayFunction->Identity,
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{
      "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "ScalingFunctions" -> None},
     PlotRange->{{-5, 20}, {-5, 5}},
     PlotRangeClipping->True,
     PlotRangePadding->{{0, 0}, {0, 0}},
     Ticks->{Automatic, Automatic}], ",", 
    GraphicsBox[{{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwtjXswFHgAx/esdAhLYifpwW8dpc3bVgg1ecttSUShVvRQEqe8Ni6pNEfU
qUYlHEIUCdHvmz3iItRZWucktuKU11COqdPMfWa+853PP9/vqsCjfIEMg8Fw
n8+3nv36DV0w/mco1nUnm0Hw2fnpicpH6fTC7H2fgHmfOrDAjVmbQ4tppWrP
vBf6KLEbrpXQW3J/J5z5jqD+am2DRV051TAsr/KXIYi+f6Yrt6SKrndtxGEm
wYa7Kzxf3qija/xKiwplCWz1VcNPOD6hfWBd1JQj2JjD4MjVi2iyx7XoyoXz
/5nyXBOrRmr9ZlFakjyBSmCb4qKHTbTWyWb4rCJBu+CTW77JM6oo1s6vUSKQ
VbHM1CxtpW6u1cPLWQTKqqZ8nkY7tQq076lQIzCadtbZ59lB7/nWHopkE6wv
TDq7u/MlldbPHbitNb+fITGz1uikRl7dzYwVBHYKj/Y0eIlpbJj4mqcewZab
4aoTf3XT8ZFEoetqArbork3RSgktCJqqiuQSFBSdNTUT9NDHatlmQZYEgpSO
/L6xXro7ql3e0IrgecCVGE1eH+3vbfDUsyNonJQfILavaW2+c1a1C4HOc/aT
wXP9dET0T/P+fQQTSXN8SzJIucfLtLpDCCwV3DZ4twxSzdVbehOOETB8+bWc
CCmVsK/8JIwjWPyqJkXc9Jb+3JxxxCCLYC0nr2HzySFqZnM8SZBH4N1qfDDo
h2Fa49Cv0ltCsDlB0iEQD9MSP+MWISUI2MEXLbEcoRebrocUSwnuBJrqzzFH
Kf/gTkHnKEFy80OTxupRmtb9VW7TvwS91hltfN4YzbL6YNOlwsGA7+mc/rEx
qi4seGdsw0GXj66lYcgELfsjd2BXAQelX2IDTE5N0ThtJTWTKg4Kx9+scnk/
RU1ZpeohTRwEQ+mmj9c05byWbZwe4sD7vOTPKN4n6sgqZlBjPcwMuw9FLZyh
Bq1eAzmdejjqwbH075ujlVsjXc/F60PyzKV1W68MBL41HV439ZH5daso3JCJ
IfP9u19RfdyIT3Wvi2EiWJshXMg0QPD2MykDK2WhlSsn/fWSAV7RbKX4qAXI
CG5bE9azGqKOG+t4od+jdU9BdIsTFyk2iu/cu1Wgaa9T/CKZi3aPj9J3a1ko
yeU+ONzMhdi6KkAljIUd9ozMjG3rYOCeFPJ0loW1TuvD7vOMMEb8/Q8RNeQM
GRSVXTRGxeTMh0sd6qgPmv6SFWyO5+WkP3/7MkS0MCs6q81hxJupchldhpxJ
Ww0tZQuwPv8miU/VBnv2qlQIC3yunkjpG1yOxI+q3vv5POwN//Hh+OhKROTP
LX0QbAXZXY0n45sILgts3zfv2op7GQ5BkgljHO3aFrLJ3AHKl9NlPR+boCx7
afYYccTG2fKS0OumYFw+HCvj5IwLMTrFqRnmSL0UGx2t4AHdxMjFJsMbUBw2
YqvwxQPXK3KXLrhjhVRD3VEtNT6MZikNzbNBtm+m0tPqHTB2+32IIbLDpFRv
ujbdD8yJhE2n3jjhwW27vauu+CM6jZPdznWD/50chy5pINhxO9sWVXog5rya
ep3zQZxKdilLj/XCkhfJjhoBx1BJlW/rHPJDojTuQ4EoAjJ3e9Is8vbBVkPs
nWIvRPHwLdlx4RGoKr4uKJf/BW9DZdJ6XWLwH7F6eJk=
           "]], 
          LineBox[CompressedData["
1:eJwl2Hc8Vu/7AHAyipBZISNF2WRF4z4RUaiQj4TsFC1bhZKRT5kZJR5C9t77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           "]], LineBox[CompressedData["
1:eJwVj3s01Gkcxo1r08xKNWjJbfzGDBNNGhTa903LulWbZJF13dGpXUwZ5Rop
lM66hHF2j0xK1oRDzK5TVF+L1uWgjJJaDMYtbRJlKKyec57znM8/z3Mek9Ao
L56ykpLS4XV/SS2KrLyOnA1vI5VzBz0S8RzjxdOTsljAWZUjqcnhWMC+GSWj
nYGMf+4WkZ2DMT1uwa6H/wswX+s0DcT44bpDOOfipzB4FNMeViE5gstq5K6O
9n5wpXneflDujJsTT8S4JB4EWpP6TFf6HtzpbpO1acEDWqQP+qQGdrgwcONE
f7471FCzPpx6aYMDLFhdFvau4EQW95Cqd+Ne6o2EydJv4ZZuUik9mIPFabWD
KTQMIteSm1vdWJhuHHeaMmwLb6OzbTYYGWFJbECrIMkWkj3Z1do8Q/zkamls
s5EtCIJGp/fVGmDjX7/O40TZwLx4y0en4O3Yt+pyoTKXCwe6WA/4JD1c7TZS
r25jDcv6clL9dh08QScZJYxYgaL3cxEpUwuf90rxnb5hBThMwl9y0cL+6aXV
UyFWELNTSvVR08I5P1R2hk9ZgtPhAW996ibMXb6kSVO3BJ3W82NpO77C7nk0
86MJbEjmBgn0pWTc+f5ES8Q2c6jhjWTXeavi5SxhxTUFC2rlOsIkDVXc+YKM
jw+wABv7D/s0qOCT9gEZbUUsQLyJXj0zFfzNZtHsXQsWxP7BLrTUUMY5uxRF
1GAmOFY+e5gvX0Plt3cHTroyIUr/O4pD+BpqWRv2sLVmgjJgT9fpVXTb9HgH
U50JTMvyOMH8CupuovcZ1pmB45s2cwvdz2jFxENy38gMtk7nW0cWKJBRkv+Z
NaoZbBmhRIYYKFBUiKmsZpkBT4SPTS6ULaL8hGhrr34G6D2fz2Y0fkTt+u3D
AQUMmNJsNGQvLKDuiFfSvjQGDHNIpuJLC6hJ+F9rxVkGbFMohnR1FlBadVUn
348Bcz4tbyod5pEoYkZjlykDlGruSFRy55BoxzHHeB0GDLFySr1ZcyizLW9C
dyMDmH9ffPUTvEOjeyuNPd8ToEZZrPIbn0XdV+nS+McEsKU7f8x8+AY1c+J1
3RsJ0ExxOjy/OIPuT/FbebUEyIXephnWMyj5fZbivIiAuuwIa3LFNCq7eew6
PYmAO+luLEH5BApMF/Z/E0NAY72qGef1OHowfoVfEkFAoN1qSveOcTQ4Jthn
F0QAN8OxLEcyhla0VPef9CUgkes2eWtpFImPc52GjxDQci6dH4tGUaqTwrjA
mYChqv3nnLtkKDgNrUkRAa0HF7GVtgwJ/P3/9bYnIPXE4NPTDUMoV0mrT49D
QO3elA6LkVfIisc2CGITkNRRfKom5iXauvquacyMgKMOj+7uowyg9nuH6isN
1/uMeX9y9z5H/h2ZIe/0CDhEbU+98LQPUSWFetG6BKz0yGlFp6ToXP6eIi6N
gOSfnzmcVe1FGpIDt7mbCdD6XiYjiZ6gHnHB0hnN9f1ebXKooBstp6mFzlII
uGJxOm6mohPRV/0qxeT1P2rXeZfkbWioEFWUaBDQ23/vwGbDx0jUhWz71Qhg
ev4uPuvbjAYs7pm7qxJweTvL7bc8QCjgRfiyMgFh9JKBhuIGFGl9TTpJImDJ
Z3bSS/cvxMkr9t+yzhs3jBY35dSgIj/BTJwSAflVHxZvaZehdhOXeMN1FuaG
uuzRFqJPa19kCirRA4+qN004/g8b211n
           "]]},
         Annotation[#, 
          "Charting`Private`Tag$4803#1"]& ], {}}, {{}, {}}, {{}, {}}}, {}},
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     BaseStyle->{FontFamily -> "Arial"},
     DisplayFunction->Identity,
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{
      "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "ScalingFunctions" -> None},
     PlotRange->{{-20, 10}, {-10, 10}},
     PlotRangeClipping->True,
     PlotRangePadding->{{0, 0}, {0, 0}},
     Ticks->{Automatic, Automatic}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.858661584335528*^9, 3.8586616237135*^9}, {
   3.858661751443453*^9, 3.858661861232752*^9}, {3.858661913435207*^9, 
   3.8586619395043707`*^9}, {3.858662089403344*^9, 3.858662105357795*^9}, 
   3.858662137601261*^9, 3.858662434291745*^9, 3.85866247902349*^9, 
   3.860146838442672*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"a31d57c8-45c9-4822-a2a5-9648a6079ef9"]
}, Open  ]],

Cell["\<\
Plot the conic for variable values of B, L, \[Mu], and \[Kappa], where \[Phi] \
remains a plot parameter. The values of B, L, \[Mu], and \[Kappa] can be \
manipulated by adjusting the controllers accordingly.\
\>", "Text",
 CellChangeTimes->{{3.860146707934126*^9, 
  3.8601467144284487`*^9}},ExpressionUUID->"816e7f7c-851d-400e-a0a1-\
e636629e57a8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"rV", "[", 
      RowBox[{"\[Phi]", ",", "B", ",", "L", ",", "\[Mu]", ",", "\[Kappa]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Phi]", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"B", ",", "0.8"}], "}"}], ",", "0", ",", "2", ",", "0.2"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"L", ",", "1"}], "}"}], ",", "0.1", ",", "1", ",", "0.1"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Mu]", ",", "1"}], "}"}], ",", "0.1", ",", "1", ",", "0.1"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Kappa]", ",", "1"}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "0.4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8586605992282257`*^9, 3.858660621947831*^9}, {
  3.858660663580011*^9, 3.8586606771315536`*^9}, {3.858660749242185*^9, 
  3.858660755053481*^9}, {3.858660804366501*^9, 3.8586608157802067`*^9}, {
  3.858660846422283*^9, 3.858660890804509*^9}, {3.8586609923727217`*^9, 
  3.858661002313189*^9}, {3.858661111512288*^9, 3.858661111846019*^9}, {
  3.858661158522094*^9, 3.858661248886162*^9}, {3.858661283645956*^9, 
  3.858661285320498*^9}, {3.858661392667158*^9, 3.858661443612577*^9}, {
  3.858661478393072*^9, 3.858661506465423*^9}, {3.858661551306815*^9, 
  3.858661552003579*^9}, {3.8586621670710506`*^9, 3.858662320374023*^9}, {
  3.858662392837226*^9, 3.8586624060410557`*^9}, {3.85866246564228*^9, 
  3.85866246705505*^9}, {3.8601467054373503`*^9, 3.86014672011796*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"b588109b-702b-43c6-89a3-bf339253f207"],

Cell[BoxData[
 FormBox[
  TagBox[
   FormBox[
    StyleBox[
     DynamicModuleBox[{$CellContext`B$$ = 0.8, $CellContext`L$$ = 
      0.9, $CellContext`\[Kappa]$$ = 
      0.6000000000000001, $CellContext`\[Mu]$$ = 0.6, Typeset`show$$ = True, 
      Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
      Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
      "\"untitled\"", Typeset`specs$$ = {{{
         Hold[$CellContext`B$$], 0.8}, 0, 2, 0.2}, {{
         Hold[$CellContext`L$$], 1}, 0.1, 1, 0.1}, {{
         Hold[$CellContext`\[Mu]$$], 1}, 0.1, 1, 0.1}, {{
         Hold[$CellContext`\[Kappa]$$], 1}, -1, 1, 0.4}}, Typeset`size$$ = {
      360., {107., 113.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
      Typeset`skipInitDone$$ = True, $CellContext`B$4824$$ = 
      0, $CellContext`L$4829$$ = 0, $CellContext`\[Mu]$4830$$ = 
      0, $CellContext`\[Kappa]$4831$$ = 0}, 
      DynamicBox[Manipulate`ManipulateBoxes[
       1, TraditionalForm, 
        "Variables" :> {$CellContext`B$$ = 0.8, $CellContext`L$$ = 
          1, $CellContext`\[Kappa]$$ = 1, $CellContext`\[Mu]$$ = 1}, 
        "ControllerVariables" :> {
          Hold[$CellContext`B$$, $CellContext`B$4824$$, 0], 
          Hold[$CellContext`L$$, $CellContext`L$4829$$, 0], 
          Hold[$CellContext`\[Mu]$$, $CellContext`\[Mu]$4830$$, 0], 
          Hold[$CellContext`\[Kappa]$$, $CellContext`\[Kappa]$4831$$, 0]}, 
        "OtherVariables" :> {
         Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
          Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
          Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
          Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> 
        ParametricPlot[
          $CellContext`rV[$CellContext`\[Phi], $CellContext`B$$, \
$CellContext`L$$, $CellContext`\[Mu]$$, $CellContext`\[Kappa]$$], \
{$CellContext`\[Phi], 0, 2 Pi}], 
        "Specifications" :> {{{$CellContext`B$$, 0.8}, 0, 2, 
           0.2}, {{$CellContext`L$$, 1}, 0.1, 1, 
           0.1}, {{$CellContext`\[Mu]$$, 1}, 0.1, 1, 
           0.1}, {{$CellContext`\[Kappa]$$, 1}, -1, 1, 0.4}}, "Options" :> {},
         "DefaultOptions" :> {}],
       ImageSizeCache->{405., {193., 200.}},
       SingleEvaluation->True],
      Deinitialization:>None,
      DynamicModuleValues:>{},
      SynchronousInitialization->True,
      UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
      UnsavedVariables:>{Typeset`initDone$$},
      UntrackedVariables:>{Typeset`size$$}], "Manipulate",
     Deployed->True,
     StripOnInput->False],
    TraditionalForm],
   Manipulate`InterpretManipulate[1]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.858660615041041*^9, 3.8586606223152647`*^9}, {
   3.8586606727181683`*^9, 3.858660677452338*^9}, 3.858660755731368*^9, {
   3.8586608644156923`*^9, 3.8586608911376457`*^9}, 3.8586610033174887`*^9, 
   3.858661112670484*^9, 3.858661179388188*^9, {3.858661216424466*^9, 
   3.858661249546831*^9}, 3.858661290703259*^9, {3.858661450104957*^9, 
   3.858661454259828*^9}, 3.858661506900379*^9, 3.858661544170209*^9, 
   3.858662247381419*^9, {3.858662320897749*^9, 3.858662349861705*^9}, {
   3.858662395152824*^9, 3.858662482551158*^9}, {3.8586625130011168`*^9, 
   3.858662517248391*^9}, 3.860146839004383*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"dd3051a8-02aa-4f96-a6f1-405810f693bc"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 705},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 149, 3, 97, "Title",ExpressionUUID->"7e0e5b54-d4c9-49bc-b7ed-1666862a7182"],
Cell[732, 27, 223, 4, 40, "Author",ExpressionUUID->"b8f31c66-9c73-4224-8603-aa2d294b28eb"],
Cell[958, 33, 154, 3, 42, "Date",ExpressionUUID->"97dd6f8c-0a6c-49b3-a42e-577c144dc25b"],
Cell[1115, 38, 2199, 49, 118, "Text",ExpressionUUID->"fcb346d3-3e64-490f-950c-a4515cd34d00"],
Cell[CellGroupData[{
Cell[3339, 91, 156, 3, 69, "Section",ExpressionUUID->"c2244fe2-1cb9-4f0a-b470-082978e883e4"],
Cell[3498, 96, 865, 24, 85, "Input",ExpressionUUID->"1a649f67-a2d0-441e-ad5c-12fc7f248f66"],
Cell[4366, 122, 954, 27, 80, "Input",ExpressionUUID->"2ea0a885-a7f9-46d8-9ada-90fe064da19f"],
Cell[5323, 151, 805, 20, 64, "Input",ExpressionUUID->"2c7ce0b9-e34b-4335-b970-7bdde6b3698c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6165, 176, 150, 3, 69, "Section",ExpressionUUID->"bc33fae6-c60a-48dc-bb50-c0f5e7b4e1da"],
Cell[6318, 181, 436, 8, 57, "Text",ExpressionUUID->"f251f2d5-078a-4c82-92cb-cd955563a4dc"],
Cell[CellGroupData[{
Cell[6779, 193, 4967, 137, 210, "Input",ExpressionUUID->"48f75573-507c-4a82-aa7b-808cb401d832"],
Cell[11749, 332, 56725, 981, 205, "Output",ExpressionUUID->"82141fab-54e0-4b3f-a327-a0ab3b01ad7c"],
Cell[68477, 1315, 56721, 981, 205, "Output",ExpressionUUID->"a31d57c8-45c9-4822-a2a5-9648a6079ef9"]
}, Open  ]],
Cell[125213, 2299, 360, 7, 34, "Text",ExpressionUUID->"816e7f7c-851d-400e-a0a1-e636629e57a8"],
Cell[CellGroupData[{
Cell[125598, 2310, 1814, 42, 63, "Input",ExpressionUUID->"b588109b-702b-43c6-89a3-bf339253f207"],
Cell[127415, 2354, 3388, 63, 419, "Output",ExpressionUUID->"dd3051a8-02aa-4f96-a6f1-405810f693bc"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

